@@ -1,31 +1,17 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2014-2018 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2018 Matthias Klumpp <matthias@tenstral.net>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#if !defined (__APPSTREAM_GLIB_H) && !defined (AS_COMPILATION)
+#pragma once
+
+#if !defined (__APPSTREAM_GLIB_H_INSIDE__) && !defined (AS_COMPILATION)
 #error "Only <appstream-glib.h> can be included directly."
 #endif
 
-#ifndef __AS_RELEASE_H
-#define __AS_RELEASE_H
-
 #include <glib-object.h>
 
 #include "as-checksum.h"
@@ -49,6 +35,24 @@ struct _AsReleaseClass
 	void (*_as_reserved8)	(void);
 };
 
+/**
+ * AsReleaseKind:
+ * @AS_RELEASE_KIND_UNKNOWN:		Unknown release type
+ * @AS_RELEASE_KIND_STABLE:		A stable release
+ * @AS_RELEASE_KIND_DEVELOPMENT:	A development release
+ *
+ * The release size kind.
+ *
+ * Since: 0.7.6
+ **/
+typedef enum {
+	AS_RELEASE_KIND_UNKNOWN,		/* Since: 0.7.6 */
+	AS_RELEASE_KIND_STABLE,			/* Since: 0.7.6 */
+	AS_RELEASE_KIND_DEVELOPMENT,		/* Since: 0.7.6 */
+	/*< private >*/
+	AS_RELEASE_KIND_LAST
+} AsReleaseKind;
+
 /**
  * AsReleaseState:
  * @AS_RELEASE_STATE_UNKNOWN:			Unknown state
@@ -69,6 +73,8 @@ AsRelease	*as_release_new			(void);
 gint		 as_release_vercmp		(AsRelease	*rel1,
 						 AsRelease	*rel2);
 
+AsReleaseKind	 as_release_kind_from_string	(const gchar	*kind_str);
+const gchar	*as_release_kind_to_string	(AsReleaseKind	 kind);
 AsReleaseState	 as_release_state_from_string	(const gchar	*state);
 const gchar	*as_release_state_to_string	(AsReleaseState	 state);
 
@@ -77,6 +83,7 @@ const gchar	*as_release_get_version		(AsRelease	*release);
 GBytes		*as_release_get_blob		(AsRelease	*release,
 						 const gchar	*filename);
 guint64		 as_release_get_timestamp	(AsRelease	*release);
+guint64		 as_release_get_install_duration(AsRelease	*release);
 const gchar	*as_release_get_description	(AsRelease	*release,
 						 const gchar	*locale);
 GPtrArray	*as_release_get_locations	(AsRelease	*release);
@@ -87,9 +94,12 @@ AsChecksum	*as_release_get_checksum_by_target (AsRelease	*release,
 						 AsChecksumTarget target);
 GPtrArray	*as_release_get_checksums	(AsRelease	*release);
 AsUrgencyKind	 as_release_get_urgency		(AsRelease	*release);
+AsReleaseKind	 as_release_get_kind		(AsRelease	*release);
 AsReleaseState	 as_release_get_state		(AsRelease	*release);
 guint64		 as_release_get_size		(AsRelease	*release,
 						 AsSizeKind	 kind);
+const gchar	*as_release_get_url		(AsRelease	*release,
+						 AsUrlKind	 url_kind);
 
 /* setters */
 void		 as_release_set_version		(AsRelease	*release,
@@ -99,6 +109,8 @@ void		 as_release_set_blob		(AsRelease	*release,
 						 GBytes		*blob);
 void		 as_release_set_timestamp	(AsRelease	*release,
 						 guint64	 timestamp);
+void		 as_release_set_install_duration(AsRelease	*release,
+						 guint64	 install_duration);
 void		 as_release_set_description	(AsRelease	*release,
 						 const gchar	*locale,
 						 const gchar	*description);
@@ -108,12 +120,15 @@ void		 as_release_add_checksum	(AsRelease	*release,
 						 AsChecksum	*checksum);
 void		 as_release_set_urgency		(AsRelease	*release,
 						 AsUrgencyKind	 urgency);
+void		 as_release_set_kind		(AsRelease	*release,
+						 AsReleaseKind	 kind);
 void		 as_release_set_state		(AsRelease	*release,
 						 AsReleaseState	 state);
 void		 as_release_set_size		(AsRelease	*release,
 						 AsSizeKind	 kind,
 						 guint64	 size);
+void		 as_release_set_url		(AsRelease	*release,
+						 AsUrlKind	 url_kind,
+						 const gchar	*url);
 
 G_END_DECLS
-
-#endif /* __AS_RELEASE_H */
